#
# spec file for package python3-pyside
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pyside
Version:        1.2.4
Release:        1.15
Summary:        PySide - python bindings for Qt
License:        LGPL-2.1+
Group:          Development/Languages/Python
Url:            http://qt-project.org/wiki/PySide
Source0:        https://github.com/PySide/PySide/archive/%{version}/pyside-%{version}.tar.gz
# PATCH-FIX pyside-fix-include-dir-qtgui rpm@fthiessen.de -- fixes include directory for QtGui component.
# Reported upstream: https://bugreports.qt.io/browse/PYSIDE-283
Patch0:         pyside-fix-include-dir-qtgui.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz-devel
BuildRequires:  libQtWebKit-devel
BuildRequires:  libqt4-devel >= 4.8
BuildRequires:  libshiboken-python3-devel
BuildRequires:  libxslt-devel
BuildRequires:  phonon-devel
BuildRequires:  python3-devel
BuildRequires:  python3-pyside-shiboken

%description
The PySide project provides LGPL-licensed Python bindings for the Qt
cross-platform application and UI framework. PySide Qt bindings allow both free
open source and proprietary software development and ultimately aim to support
all of the platforms as Qt itself.

%package devel
Summary:        PySide - python bindings for Qt
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       libqt4-devel
Requires:       libshiboken-python3-devel
# cmake can not handle both, python2 and python3 versions at the same time.
Conflicts:      python-pyside-devel

%description devel
The PySide project provides LGPL-licensed Python bindings for the Qt
cross-platform application and UI framework. PySide Qt bindings allow both free
open source and proprietary software development and ultimately aim to support
all of the platforms as Qt itself.

This package contains all the developer tools you need to create your own PyQt
applications.

%prep
%setup -q -n PySide-%{version}
%patch0 -p1

%build
%cmake -DCMAKE_BUILD_TYPE=Debug \
       -DBUILD_TESTS=FALSE \
       -DUSE_PYTHON3=1 \
       -DENABLE_VERSION_SUFFIX=TRUE \
       -DQT_PHONON_INCLUDE_DIR=%{_includedir}/phonon
make %{?_smp_mflags}
ctest -R qtcore || true

%install
cd build
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%fdupes %{buildroot}

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libpyside-*.so.*
%{python3_sitearch}/PySide-*/
%{python3_sitearch}/PySide/
%{_datadir}/PySide-*/

%files devel
%defattr(-,root,root)
%{_includedir}/PySide-*/
%{_libdir}/libpyside-*.so
%{_libdir}/cmake/PySide-%{version}/
%{_libdir}/pkgconfig/pyside-*.pc

%changelog
* Fri Jan 29 2016 toddrme2178@gmail.com
- Fix macros to work with python 3.5 and simplify them.
* Mon Nov  2 2015 rpm@fthiessen.de
- Update to 1.2.4:
  * PYSIDE-164: Fix possible deadlock on signal connect/emit
  * New release of pyside-Shiboken
* Wed Sep 23 2015 rpm@fthiessen.de
- Fixed SPEC to avoid conflict with python 2 version.
  * Use cmake macro and enabled ENABLE_VERSION_SUFFIX
  * Added pyside-fix-include-dir-qtgui.patch to fix position of
    installed QtGui component. Reported upstream:
    https://bugreports.qt.io/browse/PYSIDE-283
- Dropped unneeded doc package, because it had no content.
* Mon Jul 20 2015 rpm@fthiessen.de
- Ported to python3
  * Dependencies changed
  * Pathes changed
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 1.2.2:
  * Register qt.conf in Qt resource system to override the Qt builtins
  * use file system encoding instead of assumed 'ascii'
  * Bug fixes
* Thu Dec 19 2013 p.drouand@gmail.com
- Specfile clean-up
- Remove obsolete conditionnal macros
- Remove depreciated %%{py_requires} macro
- Fix Group; standard is Devel/Languages/Python
* Wed Aug 28 2013 fisiu@opensuse.org
- Update to 1.2.1:
  * Bug fixes.
  * Fix build in C++11 mode.
- Update tarball url.
* Wed Aug 29 2012 toddrme2178@gmail.com
- Update to 1.1.2
  * bugfix release
* Fri Apr 20 2012 toddrme2178@gmail.com
- Update to version 1.1.1
  * Unified toolchain! No more GeneratorRunner and ApiExtractor,
    now you just need Shiboken to compile PySide.
  * Bug Fixes;
- Removed references to GeneratorRunner and ApiExtractor in spec
  file
* Thu Feb  9 2012 toddrme2178@gmail.com
- Add documentation
* Thu Feb  9 2012 toddrme2178@gmail.com
- Update to 1.1.0
- Spec file cleanups
* Sun Nov 20 2011 cgiboudeaux@gmx.com
- Update to 1.0.8
* Sat Jan 23 2010 cgoncalves@opensuse.org
- adapt specfile to also support Fedora and Mandriva
* Wed Jan  6 2010 cgoncalves@opensuse.org
- enable phonon support
* Mon Dec 28 2009 cgoncalves@opensuse.org
- fix build on <= openSUSE 11.1 against boost 1.36
* Mon Dec 28 2009 cgoncalves@opensuse.org
- update to version 0.2.3
* Sun Dec 13 2009 cgoncalves@opensuse.org
- update to version 0.2.2
* Mon Oct  5 2009 cgoncalves@opensuse.org
- update to version 0.2.1
* Thu Sep  3 2009 cgoncalves@opensuse.org
- update to version 0.2
* Mon Aug 31 2009 cgoncalves@opensuse.org
- pyside-link_against_lutil.patch: link tests against -lutil
* Sat Aug 29 2009 cgoncalves@opensuse.org
- pyside-build_boost_1.36.patch: allow building with boost>=1.36.0
  (needs more testing to make sure pyside will work okay though)
* Fri Aug 21 2009 cgoncalves@opensuse.org
- initial package (version 0.1.4.5)
